package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.entity.TableSql;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TableSqlMapper;
import com.ruoyi.system.service.ITableSqlService;

/**
 * table 联合查询sql存储Service业务层处理
 *
 * @author ruoyi
 * @date 2023-07-19
 */
@Service
public class TableSqlServiceImpl implements ITableSqlService {
    @Autowired
    private TableSqlMapper tableSqlMapper;

    /**
     * 查询table 联合查询sql存储
     *
     * @param tId table 联合查询sql存储主键
     * @return table 联合查询sql存储
     */
    @Override
    public TableSql selectTableSqlByTId(Long tId) {
        return tableSqlMapper.selectTableSqlByTId(tId);
    }

    @Override
    public TableSql selectTableSqlByTSqlKey(String SQLKEY) {
        return tableSqlMapper.selectTableSqlByTSqlKey(SQLKEY);
    }

    /**
     * 查询table 联合查询sql存储列表
     *
     * @param tableSql table 联合查询sql存储
     * @return table 联合查询sql存储
     */
    @Override
    public List<TableSql> selectTableSqlList(TableSql tableSql) {
        return tableSqlMapper.selectTableSqlList(tableSql);
    }

    /**
     * 新增table 联合查询sql存储
     *
     * @param tableSql table 联合查询sql存储
     * @return 结果
     */
    @Override
    public int insertTableSql(TableSql tableSql) {
        tableSql.setCreateTime(DateUtils.getNowDate());
        return tableSqlMapper.insertTableSql(tableSql);
    }

    /**
     * 修改table 联合查询sql存储
     *
     * @param tableSql table 联合查询sql存储
     * @return 结果
     */
    @Override
    public int updateTableSql(TableSql tableSql) {
        tableSql.setUpdateTime(DateUtils.getNowDate());
        return tableSqlMapper.updateTableSql(tableSql);
    }

    /**
     * 批量删除table 联合查询sql存储
     *
     * @param tIds 需要删除的table 联合查询sql存储主键
     * @return 结果
     */
    @Override
    public int deleteTableSqlByTIds(Long[] tIds) {
        return tableSqlMapper.deleteTableSqlByTIds(tIds);
    }

    /**
     * 删除table 联合查询sql存储信息
     *
     * @param tId table 联合查询sql存储主键
     * @return 结果
     */
    @Override
    public int deleteTableSqlByTId(Long tId) {
        return tableSqlMapper.deleteTableSqlByTId(tId);
    }
}
